/* KEYSPEED.C
Set the typeamatic rate and delay on the keyboard

Version:    07-15-90
Compiler:   Turbo C++
Uses:       stdio.h, stdlib.h, dos.h, bios.h
model:      tiny

After compiling this code under the tiny model, use EXE2BIN to
convert the EXE to a BIN file.  Then rename the BIN to COM.

original code by Marty Franz from his
article in the April/May 1990 PC-TECHNIQUES pp 42-43.

Ported to Turbo C and modified to give a more helpful
usage output by Jerry LaVeck
*/

#include <stdio.h>
#include <stdlib.h>
#include <dos.h>
#include <bios.h>

#define KEYBOARD 0x16         /* keyboard interrupt */
#define SET_RATES 0x0305      /* services to set rate and delay */

char *rates[32] =
{
    "30.0",  "26.7",  "24.0",  "21.8",  "20.8",  "18.5",  "17.1",
    "16.0",  "15.0",  "13.3",  "12.0",  "10.9",  "10.0",  "9.2",
    "8.6",   "8.0",   "7.5",   "6.7",   "6.0",   "5.5",   "5.0",
    "4.6",   "4.3",   "4.0",   "3.7",   "3.3",   "3.0",   "2.7",
    "2.5",   "2.3",   "2.1",   "2.0"
};

char *delays[4] =
{
    "250",  "500", "750", "1000"
};

void main(int argc, char *argv[], char *env[])
{
	int temp, x;
	union REGS inregs, outregs;

	if (argc != 3)
	{
		printf("Usage: %s <rate> <delay>\n", argv[0]);
		puts("Sets keyboard typeamatic rate and delay.");
		printf("\n");
		puts("use 0 0 for fastest,      31 3 for slowest");
		printf("\n");
		printf("rate   repeats/sec  rate   repeats/sec  rate   repeats/sec  rate   repeats/sec\n");
		for(x = 0; x < 32; x++)	printf("%3d      %-10s ",x,rates[x]); printf("\n");
		printf("\n");
		printf("delay  milliseconds delay  milliseconds delay  milliseconds delay  milliseconds\n");
		for(x = 0; x < 4; x++)	printf("%3d      %-10s ",x,delays[x]);
		exit(1);

	}
inregs.x.ax = SET_RATES;
temp = atoi(argv[1]);
inregs.h.bl = (temp < 0x20) ? temp : 0x1f;
temp = atoi(argv[2]);
inregs.h.bh = (temp < 0x04) ? temp : 0x03;
printf("Rate:  %s characters/second\nDelay: %s milliseconds\n",
        rates[inregs.h.bl], delays[inregs.h.bh]);

int86(KEYBOARD, &inregs, &outregs);
exit(0);
}

